=======
History
=======

0.2.0 (2019-08)
------------------

* Use OOP to define call function
* Properer validation and typecast
* Improve Type Annotations

0.1.0 (2019-08-01)
------------------

* Init Project.
